@@ -9,6 +9,8 @@ if DJANGO_VERSION >= (4, 1):
 else:
     from django.contrib.auth.views import SuccessURLAllowedHostsMixin as RedirectURLMixin
 
+from wagtail import VERSION as WAGTAIL_VERSION
+
 from django.core.exceptions import PermissionDenied
 from django.http import HttpResponse
 from django.shortcuts import resolve_url
@@ -23,16 +25,19 @@ from django.views.generic import (
 from django_otp import login as otp_login
 from django_otp.plugins.otp_totp.models import TOTPDevice
 
-from wagtail import VERSION as WAGTAIL_VERSION
 from wagtail_2fa import forms, utils
 from wagtail_2fa.mixins import OtpRequiredMixin
 
 
 class LoginView(RedirectURLMixin, FormView):
-    if WAGTAIL_VERSION >= (4, 0, 0):
+
+    if WAGTAIL_VERSION >= (6, 0):
+        template_name = "wagtail_2fa/otp_form_v6.html"
+    elif WAGTAIL_VERSION < (6, 0) and WAGTAIL_VERSION >= (5, 0):
         template_name = "wagtail_2fa/otp_form.html"
     else:
         template_name = "wagtail_2fa/legacy/otp_form.html"
+
     form_class = forms.TokenForm
     redirect_field_name = REDIRECT_FIELD_NAME
 
